@@ -6,7 +6,7 @@ libtmux.window
 """
 import dataclasses
 import logging
-import os
+import pathlib
 import shlex
 import typing as t
 import warnings
@@ -80,6 +80,7 @@ class Window(Obj):
     server: "Server"
 
     def refresh(self) -> None:
+        """Refresh window attributes from tmux."""
         assert isinstance(self.window_id, str)
         return super()._refresh(
             obj_key="window_id",
@@ -89,6 +90,7 @@ class Window(Obj):
 
     @classmethod
     def from_window_id(cls, server: "Server", window_id: str) -> "Window":
+        """Create Window from existing window_id."""
         window = fetch_obj(
             obj_key="window_id",
             obj_id=window_id,
@@ -100,6 +102,7 @@ class Window(Obj):
 
     @property
     def session(self) -> "Session":
+        """Parent session of window."""
         assert isinstance(self.session_id, str)
         from libtmux.session import Session
 
@@ -113,20 +116,22 @@ class Window(Obj):
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.panes.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        panes: t.List["Pane"] = []
-        for obj in fetch_objs(
-            list_cmd="list-panes",
-            list_extra_args=["-t", str(self.window_id)],
-            server=self.server,
-        ):
-            if obj.get("window_id") == self.window_id:
-                panes.append(Pane(server=self.server, **obj))
+        panes: t.List["Pane"] = [
+            Pane(server=self.server, **obj)
+            for obj in fetch_objs(
+                list_cmd="list-panes",
+                list_extra_args=["-t", str(self.window_id)],
+                server=self.server,
+            )
+            if obj.get("window_id") == self.window_id
+        ]
 
         return QueryList(panes)
 
-    #
-    # Command (pane-scoped)
-    #
+    """
+    Commands (pane-scoped)
+    """
+
     def cmd(self, cmd: str, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
         """Return :meth:`Server.cmd` defaulting to ``target_window`` as target.
 
@@ -136,13 +141,14 @@ class Window(Obj):
         ``args`` will override using the object's ``window_id`` as target.
         """
         if not any(arg.startswith("-t") for arg in args):
-            args = ("-t", self.window_id) + args
+            args = ("-t", self.window_id, *args)
 
         return self.server.cmd(cmd, *args, **kwargs)
 
-    #
-    # Commands (tmux-like)
-    #
+    """
+    Commands (tmux-like)
+    """
+
     def select_pane(self, target_pane: t.Union[str, int]) -> t.Optional["Pane"]:
         """
         Return selected :class:`Pane` through ``$ tmux select-pane``.
@@ -156,7 +162,6 @@ class Window(Obj):
         ------
         :class:`Pane`
         """
-
         if target_pane in ["-l", "-U", "-D", "-L", "-R"]:
             proc = self.cmd("select-pane", "-t%s" % self.window_id, target_pane)
         else:
@@ -207,7 +212,6 @@ class Window(Obj):
 
         Notes
         -----
-
         :term:`tmux(1)` will move window to the new pane if the
         ``split-window`` target is off screen. tmux handles the ``-d`` the
         same way as ``new-window`` and ``attach`` in
@@ -219,21 +223,17 @@ class Window(Obj):
         """
         tmux_formats = ["#{pane_id}" + FORMAT_SEPARATOR]
 
-        # '-t%s' % self.attached_pane.get('pane_id'),
-        # 2013-10-18 LOOK AT THIS, rm'd it..
-        tmux_args: t.Tuple[str, ...] = tuple()
+        tmux_args: t.Tuple[str, ...] = ()
 
         if target is not None:
             tmux_args += ("-t%s" % target,)
         else:
             if len(self.panes):
                 tmux_args += (
-                    "-t%s:%s.%s"
-                    % (self.session_id, self.window_id, self.panes[0].pane_index),
+                    f"-t{self.session_id}:{self.window_id}.{self.panes[0].pane_index}",
                 )
             else:
-                tmux_args += ("-t%s:%s" % (self.session_id, self.window_id),)
-            # tmux_args += ("-t%s" % self.panes[0].pane_id,)
+                tmux_args += (f"-t{self.session_id}:{self.window_id}",)
 
         if vertical:
             tmux_args += ("-v",)
@@ -245,10 +245,10 @@ class Window(Obj):
 
         tmux_args += ("-P", "-F%s" % "".join(tmux_formats))  # output
 
-        if start_directory:
+        if start_directory is not None:
             # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
-            start_directory = os.path.expanduser(start_directory)
-            tmux_args += ("-c%s" % start_directory,)
+            start_path = pathlib.Path(start_directory).expanduser()
+            tmux_args += (f"-c{start_path}",)
 
         if not attach:
             tmux_args += ("-d",)
@@ -285,7 +285,9 @@ class Window(Obj):
         return self.select_pane("-l")
 
     def select_layout(self, layout: t.Optional[str] = None) -> "Window":
-        """Wrapper for ``$ tmux select-layout <layout>``.
+        """Select layout for window.
+
+        Wrapper for ``$ tmux select-layout <layout>``.
 
         Parameters
         ----------
@@ -313,7 +315,7 @@ class Window(Obj):
             'custom'
                 custom dimensions (see :term:`tmux(1)` manpages).
         """
-        cmd = ["select-layout", "-t{}:{}".format(self.session_id, self.window_index)]
+        cmd = ["select-layout", f"-t{self.session_id}:{self.window_index}"]
 
         if layout:  # tmux allows select-layout without args
             cmd.append(layout)
@@ -326,8 +328,9 @@ class Window(Obj):
         return self
 
     def set_window_option(self, option: str, value: t.Union[int, str]) -> "Window":
-        """
-        Wrapper for ``$ tmux set-window-option <option> <value>``.
+        """Set option for tmux window.
+
+        Wraps ``$ tmux set-window-option <option> <value>``.
 
         Parameters
         ----------
@@ -342,9 +345,6 @@ class Window(Obj):
         :exc:`exc.OptionError`, :exc:`exc.UnknownOption`,
         :exc:`exc.InvalidOption`, :exc:`exc.AmbiguousOption`
         """
-
-        self.refresh()
-
         if isinstance(value, bool) and value:
             value = "on"
         elif isinstance(value, bool) and not value:
@@ -352,7 +352,7 @@ class Window(Obj):
 
         cmd = self.cmd(
             "set-window-option",
-            "-t{}:{}".format(self.session_id, self.window_index),
+            f"-t{self.session_id}:{self.window_index}",
             option,
             value,
         )
@@ -378,7 +378,7 @@ class Window(Obj):
         g : str, optional
             Pass ``-g`` flag for global variable, default False.
         """
-        tmux_args: t.Tuple[str, ...] = tuple()
+        tmux_args: t.Tuple[str, ...] = ()
 
         if g:
             tmux_args += ("-g",)
@@ -422,7 +422,7 @@ class Window(Obj):
         :exc:`exc.OptionError`, :exc:`exc.UnknownOption`,
         :exc:`exc.InvalidOption`, :exc:`exc.AmbiguousOption`
         """
-        tmux_args: t.Tuple[t.Union[str, int], ...] = tuple()
+        tmux_args: t.Tuple[t.Union[str, int], ...] = ()
 
         if g:
             tmux_args += ("-g",)
@@ -439,7 +439,7 @@ class Window(Obj):
         if not len(window_options_output):
             return None
 
-        value_raw = [shlex.split(item) for item in window_options_output][0]
+        value_raw = next(shlex.split(item) for item in window_options_output)
 
         value: t.Union[str, int] = (
             int(value_raw[1]) if value_raw[1].isdigit() else value_raw[1]
@@ -458,7 +458,6 @@ class Window(Obj):
 
         Examples
         --------
-
         >>> window = session.attached_window
 
         >>> window.rename_window('My project')
@@ -467,7 +466,6 @@ class Window(Obj):
         >>> window.rename_window('New name')
         Window(@1 1:New name, Session($1 ...))
         """
-
         import shlex
 
         lex = shlex.shlex(new_name)
@@ -477,8 +475,8 @@ class Window(Obj):
         try:
             self.cmd("rename-window", new_name)
             self.window_name = new_name
-        except Exception as e:
-            logger.error(e)
+        except Exception:
+            logger.exception(f"Error renaming window to {new_name}")
 
         self.refresh()
 
@@ -486,10 +484,9 @@ class Window(Obj):
 
     def kill_window(self) -> None:
         """Kill the current :class:`Window` object. ``$ tmux kill-window``."""
-
         proc = self.cmd(
             "kill-window",
-            "-t{}:{}".format(self.session_id, self.window_index),
+            f"-t{self.session_id}:{self.window_index}",
         )
 
         if proc.stderr:
@@ -513,7 +510,7 @@ class Window(Obj):
         session = session or self.session_id
         proc = self.cmd(
             "move-window",
-            "-s{}:{}".format(self.session_id, self.window_index),
+            f"-s{self.session_id}:{self.window_index}",
             f"-t{session}:{destination}",
         )
 
@@ -556,10 +553,13 @@ class Window(Obj):
     # Dunder
     #
     def __eq__(self, other: object) -> bool:
-        assert isinstance(other, Window)
-        return self.window_id == other.window_id
+        """Equal operator for :class:`Window` object."""
+        if isinstance(other, Window):
+            return self.window_id == other.window_id
+        return False
 
     def __repr__(self) -> str:
+        """Representation of :class:`Window` object."""
         return "{}({} {}:{}, {})".format(
             self.__class__.__name__,
             self.window_id,
@@ -573,7 +573,7 @@ class Window(Obj):
     #
     @property
     def id(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_id`
+        """Alias of :attr:`Window.window_id`.
 
         >>> window.id
         '@1'
@@ -585,7 +585,7 @@ class Window(Obj):
 
     @property
     def name(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_name`
+        """Alias of :attr:`Window.window_name`.
 
         >>> window.name
         '...'
@@ -597,7 +597,7 @@ class Window(Obj):
 
     @property
     def index(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_index`
+        """Alias of :attr:`Window.window_index`.
 
         >>> window.index
         '1'
@@ -609,7 +609,7 @@ class Window(Obj):
 
     @property
     def height(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_height`
+        """Alias of :attr:`Window.window_height`.
 
         >>> window.height.isdigit()
         True
@@ -621,7 +621,7 @@ class Window(Obj):
 
     @property
     def width(self) -> t.Optional[str]:
-        """Alias of :attr:`Window.window_width`
+        """Alias of :attr:`Window.window_width`.
 
         >>> window.width.isdigit()
         True
@@ -635,48 +635,74 @@ class Window(Obj):
     # Legacy: Redundant stuff we want to remove
     #
     def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
-        """
+        """Return key-based lookup. Deprecated by attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated by attribute lookup.e.g. ``window['window_name']`` is now
+           accessed via ``window.window_name``.
+
         """
-        warnings.warn("Window.get() is deprecated")
+        warnings.warn("Window.get() is deprecated", stacklevel=2)
         return getattr(self, key, default)
 
     def __getitem__(self, key: str) -> t.Any:
-        """
+        """Return item lookup by key. Deprecated in favor of attributes.
+
         .. deprecated:: 0.16
+
+           Deprecated in favor of attributes. e.g. ``window['window_name']`` is now
+           accessed via ``window.window_name``.
+
         """
-        warnings.warn(f"Item lookups, e.g. window['{key}'] is deprecated")
+        warnings.warn(f"Item lookups, e.g. window['{key}'] is deprecated", stacklevel=2)
         return getattr(self, key)
 
     def get_by_id(self, id: str) -> t.Optional[Pane]:
-        """
+        """Return pane by id. Deprecated in favor of :meth:`.panes.get()`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.panes.get()`.
+
         """
-        warnings.warn("Window.get_by_id() is deprecated")
+        warnings.warn("Window.get_by_id() is deprecated", stacklevel=2)
         return self.panes.get(pane_id=id, default=None)
 
     def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Pane]:
-        """
+        """Filter through panes, return list of :class:`Pane`.
+
         .. deprecated:: 0.16
+
+           Deprecated by :meth:`.panes.filter()`.
+
         """
-        warnings.warn("Window.where() is deprecated")
+        warnings.warn("Window.where() is deprecated", stacklevel=2)
         try:
             return self.panes.filter(**kwargs)
         except IndexError:
             return []
 
     def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Pane]:
-        """
+        """Filter through panes, return first :class:`Pane`.
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :meth:`.panes.get()`.
+
         """
-        warnings.warn("Window.find_where() is deprecated")
+        warnings.warn("Window.find_where() is deprecated", stacklevel=2)
         return self.panes.get(default=None, **kwargs)
 
     def _list_panes(self) -> t.List[PaneDict]:
-        """
+        """Return list of panes (deprecated in favor of :meth:`.panes`).
+
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
-        warnings.warn("Window._list_panes() is deprecated")
+        warnings.warn("Window._list_panes() is deprecated", stacklevel=2)
         return [pane.__dict__ for pane in self.panes]
 
     @property
@@ -684,23 +710,32 @@ class Window(Obj):
         """Property / alias to return :meth:`~._list_panes`.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
-        warnings.warn("_panes is deprecated")
+        warnings.warn("_panes is deprecated", stacklevel=2)
         return self._list_panes()
 
     def list_panes(self) -> t.List["Pane"]:
         """Return list of :class:`Pane` for the window.
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
-        warnings.warn("list_panes() is deprecated")
+        warnings.warn("list_panes() is deprecated", stacklevel=2)
         return self.panes
 
     @property
     def children(self) -> QueryList["Pane"]:  # type:ignore
-        """Was used by TmuxRelationalObject (but that's longer used in this class)
+        """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
+
+           Slated to be removed in favor of :attr:`.panes`.
+
         """
-        warnings.warn("Server.children is deprecated")
+        warnings.warn("Server.children is deprecated", stacklevel=2)
         return self.panes
